==> bluegenes-0.9.6-20181008.130140-1.jar: META-INF/leiningen/org.intermine/bluegenes/README.md <==


# BlueGenes
## About
BlueGenes is designed to make searching and analysing genomic data easy. It's powered by [InterMine](http://intermine.org/) web services, meaning that the data from over 30 InterMines worldwide can be accessed from the same familiar interface.

[Try BlueGenes now](http://bluegenes.apps.intermine.org/)


![BlueGene screenshots](http://i.imgur.com/zwp0uxM.jpg)

**Feedback:** Please create an issue in this repo or email `info - at - intermine - dot - org`

## Setting up your dev environment and running BlueGenes

- **Development BlueGenes** If you want to run BlueGenes locally so that you can modify it, please see [docs/getting-started](docs/getting-started.md).
- **BlueGenes as built into InterMine 2.0** If you have upgraded to InterMine 2.0 (the Gradle release), see the [instructions to launch a BlueGenes target](https://intermine.readthedocs.io/en/intermine-2.0/system-requirements/software/gradle/index.html#deploy-blue-genes). 
- **Standalone BlueGenes** If you'd like to launch BlueGenes without it being associated directly with a single InterMine, or if you haven't upgraded to InterMine 2.0 yet (but you're above 1.8), please see [docs/production-builds](docs/production-builds.md).

In all cases, you may also wish to see the [docs](docs/index.md) and [BlueGenes config instructions](docs/configuring-bluegenes.md)

### Further help needed?

- If you think the issue is related to InterMine or its webservices, check out the [InterMine documentation](http://intermine.readthedocs.io/en/latest/about/contact-us/)
- Email our [dev list](http://intermine.readthedocs.io/en/latest/support/mailing-list/)
- Pop by and say hi in our [chat](http://chat.intermine.org) during UK office hours

==> bluegenes-0.9.8-20181107.121030-2.jar: META-INF/leiningen/org.intermine/bluegenes/README.md <==


# BlueGenes

[![Build Status](https://travis-ci.org/intermine/bluegenes.svg?branch=dev)](https://travis-ci.org/intermine/bluegenes)

## About
BlueGenes is designed to make searching and analysing genomic data easy. It's powered by [InterMine](http://intermine.org/) web services, meaning that the data from over 30 InterMines worldwide can be accessed from the same familiar interface.

[Try BlueGenes now](http://bluegenes.apps.intermine.org/)


![BlueGene screenshots](http://i.imgur.com/zwp0uxM.jpg)

**Feedback:** Please create an issue in this repo or email `info - at - intermine - dot - org`

## Setting up your dev environment and running BlueGenes

- **Development BlueGenes** If you want to run BlueGenes locally so that you can modify it, please see [docs/getting-started](docs/getting-started.md).
- **BlueGenes as built into InterMine 2.0** If you have upgraded to InterMine 2.0 (the Gradle release), see the [instructions to launch a BlueGenes target](https://intermine.readthedocs.io/en/intermine-2.0/system-requirements/software/gradle/index.html#deploy-blue-genes). 
- **Standalone BlueGenes** If you'd like to launch BlueGenes without it being associated directly with a single InterMine, or if you haven't upgraded to InterMine 2.0 yet (but you're above 1.8), please see [docs/production-builds](docs/production-builds.md).

In all cases, you may also wish to see the [docs](docs/index.md) and [BlueGenes config instructions](docs/configuring-bluegenes.md)

### Further help needed?

- If you think the issue is related to InterMine or its webservices, check out the [InterMine documentation](http://intermine.readthedocs.io/en/latest/about/contact-us/)
- Email our [dev list](http://intermine.readthedocs.io/en/latest/support/mailing-list/)
- Pop by and say hi in our [chat](http://chat.intermine.org) during UK office hours
